@@ -33,14 +33,6 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
-var { ExtensionCommon } = ChromeUtils.import(
-  "resource://gre/modules/ExtensionCommon.jsm"
-);
-var { ExtensionUtils } = ChromeUtils.import(
-  "resource://gre/modules/ExtensionUtils.jsm"
-);
-var { Services } = ChromeUtils.import("resource://gre/modules/Services.jsm");
-
 var { ExtensionError } = ExtensionUtils;
 
 var LegacyPrefs = class extends ExtensionCommon.ExtensionAPI {
@@ -205,4 +197,4 @@ var LegacyPrefs = class extends ExtensionCommon.ExtensionAPI {
       },
     };
   }
-};
\ No newline at end of file
+};
